# takanori-cli

Takanori commands to automate daily works.

# Install

```bash
pip install takanori-cli
```

# Usage

## Create plugins

Execute commands below.

```bash
taka plugin create
```

And answer some questions to generate a pacpage from [a template](https://github.com/takavfx/takanori-cli-plugin-template). It's also available to create a pcakge from custom templates by using `-t` or `--template` options.

```bash
taka plugin create --template <custom_template>
```
